@@ -1,9 +1,8 @@
 package Devel::Examine::Subs;
-use Devel::Trace::Subs qw(trace trace_dump); # injected by Devel::Trace::Subs
 use warnings;
 use strict;
 
-our $VERSION = '1.31';
+our $VERSION = '1.32';
 
 use Carp;
 use Data::Compare;
@@ -17,7 +16,6 @@ use Symbol;
 use Tie::File;
 
 sub new {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = {};
     bless $self, shift;
@@ -33,7 +31,6 @@ sub new {
     return $self;
 }
 sub run {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -57,7 +54,6 @@ sub run {
     return $struct;
 }
 sub _run_directory {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -67,7 +63,6 @@ sub _run_directory {
     my $dir = $self->{params}{file};
 
     find({wanted => sub {
-            trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
             return if ! -f;
 
             my @extensions = @{$self->{params}{extensions}};
@@ -101,7 +96,6 @@ sub _run_directory {
     return \%struct;
 }
 sub _run_end {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $value = shift;
@@ -111,7 +105,6 @@ sub _run_end {
     return $self->{run_end};
 }
 sub _cache {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $file = shift if @_;
@@ -134,13 +127,11 @@ sub _cache {
     }
 }
 sub _cache_enabled {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     return $self->{params}{cache};
 }
 sub _cache_safe {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $value = shift;
@@ -150,14 +141,12 @@ sub _cache_safe {
     return $self->{cache_safe};
 }
 sub _params {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my %params = @_;
     return \%params;
 }
 sub _config {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -252,7 +241,6 @@ sub _config {
     }
 }
 sub _clean_config {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $config_vars = shift; # href of valid params
@@ -279,7 +267,6 @@ sub _clean_config {
     }
 }
 sub _clean_core_config {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     # deletes core phase info after each run
 
@@ -296,7 +283,6 @@ sub _clean_core_config {
     }
 }
 sub _file {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
 
     my $self = shift;
@@ -354,7 +340,6 @@ sub _file {
    return $self->{params}{file};
 }
 sub _core {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     
     my $self = shift;
 
@@ -448,7 +433,6 @@ sub _core {
     return $subs;
 }
 sub _subs {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     
     my $self = shift;
     
@@ -520,7 +504,6 @@ sub _subs {
     return \%subs;
 }
 sub _pre_proc {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -577,7 +560,6 @@ sub _pre_proc {
     return $cref;
 }
 sub _pre_filter {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -654,7 +636,6 @@ sub _pre_filter {
     return @pre_filters;
 }
 sub _engine {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -709,7 +690,6 @@ sub _engine {
     return $cref;
 }
 sub pre_procs {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $module = $self->{namespace} . "::Preprocessor";
@@ -723,7 +703,6 @@ sub pre_procs {
     return @pre_procs;
 }
 sub pre_filters {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $module = $self->{namespace} . "::Prefilter";
@@ -737,7 +716,6 @@ sub pre_filters {
     return @pre_filters;
 }
 sub engines {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $module = $self->{namespace} . "::Engine";
@@ -751,7 +729,6 @@ sub engines {
     return @engines;
 }
 sub has {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -762,7 +739,6 @@ sub has {
     $self->run($p);
 }
 sub missing {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -772,7 +748,6 @@ sub missing {
     $self->run($p);
 }
 sub all {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -782,7 +757,6 @@ sub all {
     $self->run($p);
 }
 sub lines {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -796,7 +770,6 @@ sub lines {
     $self->run($p);
 }
 sub module {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -812,7 +785,6 @@ sub module {
     $self->run($p);
 }
 sub objects {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -823,7 +795,6 @@ sub objects {
     $self->run($p);
 }
 sub search_replace {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -836,7 +807,6 @@ sub search_replace {
     $self->run($p);
 }
 sub inject {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     my $self = shift;
     my $p = $self->_params(@_);
 
@@ -850,7 +820,6 @@ sub inject {
     $self->run($p);
 }
 sub remove {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -861,7 +830,6 @@ sub remove {
     $self->run($p);
 }
 sub inject_after {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -878,7 +846,6 @@ sub inject_after {
     $self->run($p);
 }
 sub add_functionality {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     
     my $self = shift;
     my $p = $self->_params(@_);
@@ -902,7 +869,6 @@ sub add_functionality {
 
     my %dt = (
             engine => sub {
-                        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
                         return $in_prod
                         ? $INC{'Devel/Examine/Subs/Engine.pm'}
                         : 'lib/Devel/Examine/Subs/Engine.pm';
@@ -944,7 +910,6 @@ sub add_functionality {
     push @TIE_file, @code;
 }
 sub valid_params {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     return %{$self->{valid_params}};
@@ -1267,21 +1232,9 @@ details.
 
 
 
-=head2 C<pre_procs>
-
-Returns a list of all available pre processor modules.
 
 
 
-=head2 C<pre_filters>
-
-Returns a list of all available built-in pre engine filter modules.
-
-
-
-=head2 C<engines>
-
-Returns a list of all available built-in 'engine' modules.
 
 
 =head2 C<valid_params>
@@ -1365,7 +1318,9 @@ change the copy. Useful for verifying the changes took properly.
 =back
 
 
+=head2 C<pre_procs>, C<pre_filters>, C<engines>
 
+For development. Returns the list of the respective built-in callbacks.
 
 
 
@@ -1597,14 +1552,11 @@ will be executed based on their order in the array reference.
 
 =back
 
-=head1 DEBUGGING
-
-This module is equipped with the C<Devel::Trace::Subs> module.
-
-To enable trace debugging, set C<$ENV{DTS_ENABLE}> and C<$ENV{DES_TRACE}>
-environment variables to true values in the calling script.
 
 
+=head1 REPOSITORY
+
+L<https://github.com/stevieb9/devel-examine-subs>
 
 
 
