@@ -1,6 +1,5 @@
 package Devel::Examine::Subs::Engine;
 
-use Devel::Trace::Subs qw(trace trace_dump); # injected by Devel::Trace::Subs
 use strict;
 use warnings;
 
@@ -11,10 +10,9 @@ use Devel::Examine::Subs::Sub;
 use File::Copy;
 use Tie::File;
 
-our $VERSION = '1.31';
+our $VERSION = '1.32';
 
 sub new {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = {};
     bless $self, shift;
@@ -24,7 +22,6 @@ sub new {
     return $self;
 }
 sub _dt {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
 
@@ -46,7 +43,6 @@ sub _dt {
     return $dt;
 }
 sub exists {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $string = shift;
@@ -59,26 +55,20 @@ sub exists {
     }
 }
 sub _test {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
         return {a => 1};
     };
 }
 sub _test_print {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
         print "Hello, world!\n";
     };
 }
 sub all {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
         my $p = shift;
         my $struct = shift;
@@ -91,10 +81,8 @@ sub all {
     };
 }
 sub has {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
         
         my $p = shift;
         my $struct = shift;
@@ -109,10 +97,8 @@ sub has {
     };
 }
 sub missing {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
         my $p = shift;
         my $struct = shift;
@@ -147,10 +133,8 @@ sub missing {
     };
 }
 sub lines {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
         
         my $p = shift;
         my $struct = shift;
@@ -171,12 +155,10 @@ sub lines {
     };
 }
 sub objects {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     # uses 'subs' pre_filter
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
         my $p = shift;
         my $struct = shift;
@@ -231,10 +213,8 @@ sub objects {
     };
 }
 sub search_replace {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
         my $p = shift;
         my $struct = shift;
@@ -313,10 +293,8 @@ sub search_replace {
     };                        
 }
 sub inject_after {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
         my $p = shift;
         my $struct = shift;
