@@ -1,16 +1,14 @@
 package Devel::Examine::Subs::Preprocessor;
 
-use Devel::Trace::Subs qw(trace trace_dump); # injected by Devel::Trace::Subs
 use strict; 
 use warnings;
 
 use Carp;
 use Data::Dumper;
 
-our $VERSION = '1.31';
+our $VERSION = '1.32';
 
 sub new {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = {};
     bless $self, shift;
@@ -23,7 +21,6 @@ sub new {
 }
 
 sub _dt {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
 
@@ -38,7 +35,6 @@ sub _dt {
 }
 
 sub exists {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     my $self = shift;
     my $string = shift;
 
@@ -51,10 +47,8 @@ sub exists {
 }
 
 sub module {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
         no strict 'refs';
 
@@ -84,10 +78,8 @@ sub module {
 }
 
 sub inject {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
         my $p = shift;
         my $file = $p->{file};
@@ -184,10 +176,8 @@ sub inject {
 }
 
 sub remove {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
         
         my $p = shift;
         my $file = $p->{file};        
